@@ -232,6 +232,7 @@ class to_sql(Read_sql):
         self.delete_cache = kwargs.pop('delete_cache')
         self.save_path = kwargs.pop('save_path',None)
         self.thread_w = kwargs.pop('thread_w',3)
+        self.delete_sql= kwargs.pop('delete_sql',None)
         self.dir_path = None
         self.task_count = None
         self.execute_count = 0
@@ -253,6 +254,8 @@ class to_sql(Read_sql):
         sql = 'delete ' + re.search('from.*', sql, re.I).group()
         con = self.to_db.get_db()
         db = con.cursor()
+        if self.delete_sql is not None:
+            sql = self.delete_sql
         db.execute(sql)
         con.commit()
         self.to_db.close_db(con)
@@ -393,12 +396,13 @@ class to_sql(Read_sql):
                 df[column] = df[column].astype('str')
         con = self.to_db.get_db()
         db = con.cursor()
-        columns = df.columns.tolist()
-        sql = self.get_sql(columns)
 
         if self.to_columns is not None:
             df = df[self.to_columns]
 
+        columns = df.columns.tolist()
+        sql = self.get_sql(columns)
+
         try:
             db.executemany(sql, df.values.tolist())
         except Exception as e:
